# Accepted Manuscript

Title: Humeral torsion and shoulder rotation range of motion
parameters in elite swimmers

Author: Kylie Holt Craig Boettcher Mark Halaki Karen A.
Ginn

PII: S1440-2440(16)30218-3
DOI: [http://dx.doi.org/doi:10.1016/j.jsams.2016.10.002](http://dx.doi.org/doi:10.1016/j.jsams.2016.10.002)
Reference: JSAMS 1404

To appear in: _Journal of Science and Medicine in Sport_

Received date: 26-4-2016

Revised date: 23-9-2016

Accepted date: 9-10-2016

Please cite this article as: Holt Kylie, Boettcher Craig, Halaki Mark,
Ginn Karen A.Humeral torsion and shoulder rotation range of motion
parameters in elite swimmers. _Journal_ _of_ _Science_ _and_ _Medicine_ _in_ _Sport_
[http://dx.doi.org/10.1016/j.jsams.2016.10.002](http://dx.doi.org/10.1016/j.jsams.2016.10.002)

This is a PDF file of an unedited manuscript that has been accepted for publication.
As a service to our customers we are providing this early version of the manuscript.
The manuscript will undergo copyediting, typesetting, and review of the resulting proof
before it is published in its final form. Please note that during the production process
errors may be discovered which could affect the content, and all legal disclaimers that
apply to the journal pertain.

**Title**

**Humeral torsion and shoulder rotation range of motion parameters in elite swimmers**

Kylie Holt \[1\]

Craig Boettcher \[2\]

Mark Halaki \[3\]

Karen A Ginn \[2 \]

1 Department of Physical Therapies, Australian Institute of Sport, Canberra, Australia

2 Discipline of Biomedical Science, Sydney Medical School, University of Sydney, Australia

3 Discipline of Exercise & Sports Science, Faculty of Health Sciences, University of Sydney,

Australia

**Corresponding Author**

Kylie Holt, BMedSc BAppSc(Phty) MPhty(Sports)

Senior Sports Physiotherapist, Physical Therapies Department

Australian Institute of Sport, Australian Sports Commission

Leverrier Street, Bruce, ACT 2617, Australia

Tel:  +61 414791911

Fax: +61 2 6214 1753

[kylie.holt@ausport.gov.au](mailto:kylie.holt@ausport.gov.au)

**Word count:** 3193 words

1

**Abstract**

**Objectives:** Optimal shoulder rotation range of motion (ROM) for swimming is unknown.

The primary aim of this study was to examine shoulder rotation ROM in elite swimmers,

including the influence of humeral torsion on rotation ROM, in order to establish optimal

shoulder rotation parameters for swimming. In addition, we examined the relationship

between rotation ROM and shoulder pain. **Design** : descriptive cohort study **Methods:**

Seventy elite Australian swimmers provided shoulder pain history data prior to measurement

of humeral torsion and passive and active shoulder rotation ROM. Repeated measure

analyses of variance were used to investigate within and between participant differences for

all variables. Associations between humeral torsion and rotation ROM were investigated

using Pearson’s correlation coefficient. Multiple regression analysis was utilised to examine

the associations between rotation ROM and shoulder pain. **Results:** Average humeral torsion

angles of 27±10˚ (dominant side) and 31±10˚ (non-dominant side) were demonstrated in this

elite swimming cohort _._ In general, increased humeral torsion was positively associated with

increased internal rotation (IR) and decreased external rotation (ER) ROM. There were

significant differences in both IR and ER ROM measured passively and actively (F2,136≥93.1,

p\<0.001) with passive ROM greater than active ROM (p\<0.001) and active IR ROM

measured in supine greater than measured in prone (p\<0.001). There were no associations

between any rotation ROM variables and current or history of shoulder pain (r \[2\] =0.058;

p=0.46). **Conclusions:** Humeral torsion angle and passive shoulder IR ROM were similar

while passive ER ROM was greater in elite swimmers compared to reported normal

population values.

**Key words:** shoulder; shoulder pain; swimming, shoulder internal rotation; shoulder external

rotation

2

**Introduction**

In order to perform a sporting activity effectively and efficiently an athlete should meet

certain physical requirements. Being physically suited to a particular sport will in turn assist

in the prevention of injury. For example, the throwing athlete requires large ranges of

shoulder external rotation (ER) range of motion (ROM) during the throwing action. It has

been shown that reduced shoulder ER ROM in a throwing athlete can lead to decreased

performance \[1\] and increased chance of injury. \[2,3\]

Biomechanical analysis has shown that shoulder IR is the dominant movement during

freestyle swimming, \[4\] the stroke most commonly swum by all swimmers. \[5\] Consequently,

adequate shoulder IR ROM is believed to be important for both injury prevention and

performance enhancement in the swimming population. \[6\] Active shoulder IR ROM of

between 40°-50° is considered to be ideal for swimming athletes. \[6\] However, little objective

data is available to support this claim. Further examination of shoulder rotation ROM in elite

level swimmers is, therefore, warranted to determine the ideal shoulder IR ROM required for

swimming.

The orientation of the proximal end of the humerus (humeral torsion) can influence

shoulder rotation ROM measurements. \[7\] Greater humeral retrotorsion will result in increased

shoulder ER and decreased IR ROM with no change in the total shoulder ROM. In throwing

athletes, greater humeral retrotorsion is seen in the throwing arm relative to the non-throwing

arm. \[8\] It is believed that this change is due to the osseous torsional loading on the humerus

during throwing, resulting in the increased shoulder ER ROM observed in the throwing arm

of these athletes. Given the apparent need for shoulder IR ROM in swimming, it would seem

logical that swimmers may have a tendency toward more humeral antetorsion and that

humeral torsion would be symmetrical given the bilateral nature of swimming. Only one

3

study has examined humeral torsion in swimmers. \[9\] This study examined 29 young swimmers

(average age 15.9 years) and found increased humeral retrotorsion in the dominant limb i.e. a

pattern similar to that found in throwers, albeit to a lesser extent. Given the relatively young

age of the swimmers and small sample size, further examination of humeral torsion in elite

level swimmers is needed to confirm the loading effects of swimming on humeral structure.

Elite athletes are crucial to understanding the optimal physical characteristics required for

a particular athletic task so that the confounding variables of poor technique can be

controlled. Only one small study has examined the shoulder rotation ROM characteristics in

elite swimmers. \[10\] A much larger sample size is required to establish a normative database of

the optimal shoulder rotation ROM for swimming in order to draw valid associations between

variation in these parameters and the occurrence of shoulder pain.

Therefore, the aims of this study were to examine an elite swimming cohort in order to

determine the humeral torsion and shoulder rotation ROM characteristics for effective and

efficient swimming. A secondary aim was to investigate if there is an association between

changes in these physical characteristics and shoulder pain in elite swimmers.

**Methods**

Seventy (41 male and 29 female) current elite Australian swimmers aged 16 years and older

(mean±SD age = 20.1±3.3 years) were recruited. The athletes were considered elite if they

had qualified to compete in a minimum of two all-age national championships. This cohort

included 41 of the Australian swimming team who competed at the 2013 world

championships. Remaining athletes where recruited from Institute of Sport swimming

programs in Australia. All athletes provided demographic data (age, sex, hand dominance) as

well as swimming event (sprint or distance), self-estimated average weekly training load and

current and past shoulder pain status. This study was approved by the Australian Institute of

4

Sport Ethics Committee (Approval Number: 20130413) and consent was obtained from each

athlete and guardian, if applicable, prior to data collection.

Bilateral measurements of humeral torsion and passive and active shoulder rotation ROM

were taken in the one testing session. Test order was block randomised by side (dominant;

non-dominant) and measurement (torsion, ROM).

Humeral torsion was measured in supine using a non-invasive ultrasound (US) technique \[7\]

using two real time US machines (Xario XG and Toshiba XG SSA-680A) with 12 MHz

linear transducer PLT-1204BT (Toshiba Medical Systems, Tochigi, Japan) each modified

with the attachment of a spirit level on the US head. \[7\]

Internal and external shoulder rotation ROM were measured from digital photographs,

with the humerus abducted to 90° in the coronal plane and elbow in 90° flexion \[11\] . Passive

rotation ROM was measured in supine and active rotation ROM was measured in both supine

and prone (Figure 1). The scapula was stabilised manually by an examiner during passive

testing. During active testing, athletes were required to rotate their arm to their maximal

achievable IR and ER ROM while actively stabilising their scapula. Examiners provided

verbal and tactile feedback to ensure correct scapula position during active ROM testing.

Inter-rater reliability was calculated using a subset of the data (10 subjects) for all rotation

ROM measures and indicated that there were high correlations between the two raters (r ≥

0.976) with smallest detectable difference \< 0.75° for all ROM measures.

The normality of the distribution of the data was checked and confirmed using probability

plots. Two factor repeated measures analysis of variance (ANOVA) \[within participant

factor: dominance: dominant and non-dominant; between participant factor: sex: male and

female\] were used to examine differences in humeral torsion. Differences in IR and ER ROM

were examined using three factor ANOVA \[within participant factors: dominance: dominant

5

and non-dominant; execution of rotation ROM: passive, active in supine, active in prone;

between participant factor: sex: male and female\]. Tukey post-hoc test was used to identify

significant differences when significant ANOVA results were found. Effect sizes were

calculated using Cohen’s d with \<0.2 indicating nil, 0.2 to \<0.6 indicating small, 0.6 to \<0.8

indicating medium and ≥0.8 indicating large effect sizes \[12\] .

Associations between the amount of humeral torsion and shoulder rotation ROM measures

were investigated using Pearson’s correlation coefficient (r). Independent predictors of pain

(presence of shoulder pain or history of shoulder pain) were examined using multiple

regression models with the following predictors: humeral torsion, IR and ER ROM.

Significance was set at p\<0.05. Statistica (Version 10, Statsoft Inc, USA) was used for all

statistical analysis.

**Results**

Data from one male swimmer during active ROM in prone was missing. Therefore, this

athlete’s data was excluded from the ROM ANOVA but included in all other analyses.

The majority (89%) of elite swimmers examined were right-hand dominant. Thirty percent

competed in sprint events, 44% in distance events and 18% in both sprint and distance events.

Thirty percent of swimmers estimated their annual training load to be between 30 and 40 km

per week with 34% training \<30 km per week and 36% >40 km per week. Twenty-four

percent reported shoulder pain during competition and training at the time of testing with a

further 53% reporting a previous history of shoulder pain. The shoulder musculoskeletal

profile data measured in this study is summarised in Table 1.

The mean (±SD) degree of humeral torsion bilaterally in this elite swimming cohort was

27±10˚on the dominant side and 31±10˚ on the non-dominant side. There was a significant

6

interaction between sex and hand dominance (F1,68=7.34, p=0.008). Post hoc testing indicated

less humeral torsion (average difference = 6.4°) in the dominant shoulder compared to the

non-dominant shoulder of the male swimmers (Cohen’s d=0.6, small to medium effect size,

p\<0.001) with no significant differences bilaterally (average difference = 1.0°) in female

swimmers (Cohen’s d=0.13, nil effect size, p=0.904) nor between male and female swimmers

(dominant: average difference = 0.3°, Cohen’s d=0.03, nil effect size, p=0.999; non

dominant: average difference = 5.7°, Cohen’s d=0.60, small to medium effect size, p=0.082).

The mean (±SD) shoulder IR and ER ROM measured passively and actively in both

supine and prone for dominant and non-dominant shoulders is illustrated in Figure 2. There

were significant ANOVA main effects for hand dominance for IR (F1,68≥4.13, p=0.046) and

ER ROM (F1,68=6.22, p=0.015) when all ROM measures were combined. However, there

were no interactions between hand dominance and execution of rotation ROM (p>0.891).

There were no differences between dominant and non-dominant shoulders for any individual

rotation ROM measure (average rotation ROM differences between 2.2° and 2.6°, Cohen’s

d=0.16-0.19, nil effect size, p≥0.120).

There were significant ANOVA main effects for execution of rotation ROM: passive,

active in supine and active in prone (F2,136≥93.1, p\<0.001). Tukey post hoc analysis indicated

that IR ROM measured passively was greater than measured actively (average difference =

20.8°, Cohen’s d=0.96-2.08, large effect sizes, p\<0.001) and actively measured in supine was

greater than when measured in prone (average difference = 17.9°, Cohen’s d=1.30, large

effect sizes, p\<0.001). External rotation ROM measured passively was greater than active ER

ROM (average difference = 14.5°, Cohen’s d=0.99-1.19, large effect sizes, p\<0.001) with no

differences in active range measured in supine and prone (average difference = 1.7°, Cohen’s

d=0.13, nil effect size, p=0.313). There were no sex differences (Cohen’s d=0.00-0.40, nil to

small effect sizes, F1,68≤1.67, p≥0.201) nor any interaction effects (p≥0.346) for any ROM

7

measures. Correlation analysis of humeral torsion and shoulder rotation ROM indicated that,

in general, increased humeral torsion angle was associated with increased IR and decreased

ER ROM except non-dominant passive IR range and dominant active ER range measured in

prone (Figure 3).

Multiple regression analysis revealed no associations between current shoulder pain or a

history of shoulder pain with the degree of humeral torsion or any of the shoulder ROM

variables measured (r \[2\] =0.058, p=0.46).

**Discussion**

This is the first study to measure the degree of humeral torsion in elite swimming athletes.

Results indicate humeral torsion angles bilaterally of approximately 30° (dominant: 27±10˚;

non-dominant: 31±10˚) (Table 1). In general, increased humeral torsion angle was positively

associated with increased IR ROM and decreased ER ROM (Figure 3). This positive

association between increased humeral torsion and shoulder rotation ROM measures

highlights the clinical importance of measuring the total arc of shoulder rotation motion when

examining an athlete’s shoulder. Measuring shoulder IR or ER ROM in isolation may give

the impression of restriction in one direction; however, this may simply reflect bilateral

differences in the degree of humeral torsion rather than a soft tissue restriction.

As swimming is a bilateral sport that does not generate the levels of torsional stress on the

humerus encountered during overhead throwing it was predicted that these athletes would

demonstrate larger humeral torsion angles than the dominant (throwing) arm of throwing

athletes, which would not differ significantly from side to side. As expected, these elite

swimmers did demonstrate a much higher degree of humeral torsion angle in their dominant

shoulder than professional pitchers with an average humeral torsion of 27±10° (Table 1)

compared to values in pitchers between 5° to 10°. \[8\] In addition, there was no bilateral

8

difference in humeral torsion angle in the female swimmers in the current study. However,

contrary to expectation, there was a statistically significant, small to medium effect size,

difference in the degree of humeral torsion bilaterally in the male swimmers for which no

obvious explanation is immediately apparent. The non-dominant shoulder in males displayed

a greater average humeral torsion angle (33°) than their dominant shoulder (27°) and than

both shoulders in the female swimmers (dominant 27°; non-dominant 28°) (Table 1).

The elite swimming athletes in the current study demonstrated similar average humeral

torsion values as normal participants. Mean humeral torsion of 26±11° was reported in a

study using CT to measure humeral torsion in 410 normal shoulders. \[13\] Measurements of

humeral torsion in the non-dominant shoulder of elite overhead athletes, which would only be

subjected to normal day to day activities, report mean values of between 23° and 29°. \[8,14-16\]

The 6.4° mean difference in the degree of humeral torsion between dominant and non

dominant sides in the male swimmers in the current study is well within one standard

deviation of normative humeral torsion values challenging whether this difference is

functionally meaningful. \[13\] It would seem that, unlike throwing, the mechanical stresses

associated with swimming do not influence the orientation of the humeral head on its shaft.

Average passive shoulder IR ROM measured in supine lying in this elite swimming cohort

was slightly greater than 60° (dominant 61°; non-dominant 63°) and average passive ER

range slightly greater than 100° (dominant 105°; non-dominant 103°) (Table 1). There were

no significant differences, nil effect sizes, in passive shoulder rotation ROM between

dominant and non-dominant sides. It would seem that, in this large cohort of swimming

athletes currently competing at an elite level, passive shoulder rotation ROM adaptations are

equal bilaterally consistent with the bilateral demands swimming places on the upper limbs.

9

Unfortunately it is not possible to compare the ROM results in the current study to the

only other study examining shoulder rotation ROM in elite swimmers as no details are

provided in this previous study on the method used to measure rotation ROM \[17\] . The passive

shoulder rotation ranges recorded in the current study, however, are similar to other studies

that have measured passive shoulder rotation ROM in swimmers in a similar manner. In a

group of 37 female collegiate swimming athletes both with and without current shoulder pain,

average passive IR ranges slightly higher than the current study (dominant and non-dominant:

67°) and passive ER ranges slightly lower (dominant 101°; non-dominant 96°) were

reported. \[18\] In a small study of 20 older male recreational swimmers, \[19\] passive ER ROM was

slightly greater than 100° (dominant 103°; non-dominant 101°) and passive IR ROM on the

non-dominant shoulder averaged 65°, similar to the current study. However, average

dominant shoulder passive IR ROM (53°) in these non-elite swimmers \[19\] was much less than

that found in the current study. As swimming is not likely to be the main mechanical

influence on humeral structure in a non-elite population, the decreased passive shoulder IR

ROM reported in these recreational male swimmers may reflect a more retrotorted humerus

due to the influence of other dominant arm activities such as throwing.

Consistent with our finding of bilateral measurements of humeral torsion that appear to be

within normal limits, the passive shoulder IR ranges demonstrated by this elite swimming

cohort are similar to age-related control participants who were also examined in supine lying.

In a recent normative study of participants between the ages of 18-39 years, average passive

shoulder IR rotation ROM in males was found to be between 62° (dominant) and 64° (non

dominant) and in females ranged between 69° (dominant) and 68° (non-dominant) with

similar variability (standard deviations) to the current study. \[20\] However, passive shoulder ER

ROM was greater in our elite swimming cohort compared with these control participants

(Table 1). Both male and female control participants demonstrated between 14° and 16° less

10

passive ER ROM in both dominant and non-dominant shoulders. \[20\] These results would

suggest that, contrary to popular opinion, a selective increase in passive shoulder IR ROM

bilaterally is not present in elite swimming athletes. \[9\] The increased shoulder rotation

flexibility in the elite swimmers in the current study compared to age-related control

participants was due to increased passive ER ROM. As humeral external rotation is required

to achieve full shoulder elevation perhaps this finding reflects the repetitive movement into

elevation required during most swimming strokes.

During swimming athletes must be able to reach extreme ranges of motion at the

shoulder. \[21\] Therefore, active ROM i.e. the ability of the swimmer to utilize available ROM,

has been considered to be of primary importance in assessing ROM in swimmers. \[10,22,23\]

Active rotation ROM has most commonly been measured in the supine position utilized in

the current study. \[22-24\] In our cohort of elite swimmers, both active IR and ER ROM measured

in supine was less than passive rotation ROM measured in the same position (Figure 2).

Active IR ROM was 49° (dominant side) and 51° (non-dominant) compared with 61° and 63°

when measured passively. Active ER ROM was 90° (dominant side) and 87° (non-dominant

side) compared with 105° and 103° respectively when measured passively (Table 1). These

active shoulder rotation ranges do not differ markedly in magnitude from those reported in

other studies examining swimming athletes. Active IR ROM of 45-49° and active ER ROM

of 100-102° have been reported in collegiate swimmers. \[22\] In a group of high school and

collegiate swimming athletes average active IR ROM of approximately 55-60° and average

active ER ROM of approximately 86-92° have been reported. \[23\] Similarly, average bilateral

active IR ROM of approximately 54° and average bilateral active ER ROM of approximately

97° have been reported in 74 young swimmers (average age 15±3 years). \[24\]

Shoulder IR ROM of between 40-50° is considered to be ideal for swimming athletes. \[6\]

Elite swimmers in this study did demonstrate passive IR ROM and active IR ROM measured

11

in supine within this required range (Table 1). The average active IR ROM measured in

prone, however, was significantly less than that measured in supine and was less than the

range considered to be necessary for swimming (Table 1, Figure 2). Active IR performed in

prone requires shoulder internal rotators to contract concentrically while active IR performed

in supine involves eccentric contraction of shoulder external rotators. During swimming the

required shoulder IR ROM is achieved by concentric contraction of shoulder internal rotators

making prone the more functionally relevant position to assess active shoulder IR ROM in

swimmers. Based on the active IR ROM measurements performed in the functionally

relevant prone position in the elite swimmers in this study, it would seem that 30° of shoulder

IR might be a more accurate description of the active IR ROM required for efficient

swimming.

At the time of testing 24% of the elite swimming athletes reported current shoulder pain

during training and/or competition and another 53% reported a history of shoulder pain but

no current pain. Regression analysis did not reveal any significant association between

shoulder pain (current or past) and any of the shoulder rotation parameters measured in this

large cohort of swimming athletes currently competing at an elite level. These results support

the findings of previous smaller studies which reported no relationship between shoulder pain

and rotation ROM in swimming athletes. \[10,18,22\] The finding of no relationship between the

degree of humeral torsion and current or past shoulder pain in the current study provides

further evidence that rotation parameters at the shoulder are not predictive of shoulder pain in

swimming athletes who are actively competing. It remains to be seen if differences in

shoulder rotation ROM variables are present in elite swimmers whose shoulder pain prevents

them from competing.

The strength of the conclusions that can be drawn from this study are enhanced by the

size of the cohort examined and the stringent inclusion criteria employed to increase the

12

likelihood that all participants were utilising optimal swimming biomechanics. To our

knowledge this is the largest study investigating physical parameters at the shoulder in elite

swimmers. To be eligible to participate, swimmers had to have qualified to compete at the

Australian open-age national championships on at least two occasions and over half the

cohort had represented Australia in international competition. Given the success of Australian

swimming teams it would seem likely that the swimmers in this study are employing optimal

swimming technique including optimal shoulder technique.

**Practical implications**

- Elite swimmers do not display a greater degree or humeral torsion or passive IR ROM

than an age-related population not involved in competitive swimming. Therefore,

therapy to maintain normal shoulder IR ROM is sufficient to enable effective and

efficient swimming.

- Elite swimmers display approximately 15° more passive ER ROM than an age-related

population not involved in competitive swimming.

- Active shoulder IR ROM of 30° measured in prone is sufficient for effective, efficient

swimming technique.

- Humeral torsion and shoulder rotation ROM variables are not associated with

shoulder pain in elite swimming athletes performing normal training and competing

regimes.

13

**Acknowledgements**

The authors would like to thank the Australian Institute of Sport, Swimming Australia and

all the athletes who gave their time to participate in the study. This study was supported by a

Biomedical Research Initiative Grant, Discipline of Biomedical Science, The University of

Sydney.

14

**References**

1. Escamilla R, Fleisig G, Barrentine S, et al. Kinematic and kinetic comparisons

between American and Korean baseball pitchers. _Sports Biomech_ 2002;1:213-228.

2. Pieper H. Humeral torsion in the throwing arm of handball players. _Am J Sports Med_

1998;26(2):247-253.

3. Whiteley R. Baseball throwing mechanics as they relate to pathology and

performance. _J Sports Sci Med_ 2007;6:1-20.

4. Yanai T, Hay J, Miller G. Shoulder impingement in front-crawl swimming: a method

to identify impingement. _Med Sc Sport Exerc_ 2000;32:21-29.

5. Richardson A, Jobe F, Collins H. The shoulder in competitive swimming. _Am J Sports_

_Med_ 1980;8(3):159-163.

6. Blanch P. Conservative management of shoulder pain in swimmers. _Phys Ther Sport_

2004;5:109-124.

7. Whiteley R, Ginn K, Nicholson L, et al. Indirect ultrasound measurement of humeral

torsion in adolescent baseball palyers and non-athletic adults: relaibility and

significance. _J Sc Med Sport_ 2006;9(4):310-318.

8. Noonan T, Shanley E, Bailey L, et al. Professional pitchers with glenohumeral

rotation deficit (GIRD) display greater humeral retrotorsion than pitchers without

GIRD. _Am J Sports Med_ 2015;43(6):1448-1454.

9. Whiteley R, Ginn K, Nicholson L, et al. Sports participation and humeral torsion. _J_

_Orthop Sports Phys Ther_ 2009;39(4):256-263.

10. Bak K, Magnusson S. Shoulder strength and range of motion in symptomatic and

pain-free elite swimmers. _Am J Sports Med_ 1997;25(4):454-459.

11. Ginn KA, Cohen ML. Conservative treatment for shoulder pain: prognostic indicators

of outcome. _Arch Phys Med Rehabil_ 2004;85(8):1231-5.

15

12. Cohen J. _Statistical power analysis for the behavioral sciences_ . Hillsdale, N.J.: L.

Erlbaum Associates. 1988.

13. Matsumura N, Ogawa K, Kobayashi S, et al. Morphologic features of the humeral

head and glenoid version in the normal glenohumeral joint. _J Shoulder Elbow Surg_

2014;23:1724-1730.

14. Schwab L, Blanch P. Humeral torsion and passive shoulder range in elite volleyball

players. _Phys Ther Sport_ 2009;10(2):51-56.

15. Myers J, Oyama S, Goerger B, et al. Influence of humeral torsion on interpretation of

posterior shoulder tightness measures in overhead athletes. _Clin Sport Med_

2009;19(5):366-371.

16. Myers J, Oyama S, Rucinski T, et al. Humeral retrotorsion in collegiate baseball

pitchers with throwing-related upper extremity injury history. _Sports Health_

2011;3(4):383-389.

17. Bak K, Magnusson SP. Shoulder Strength and Range of Motion in Symptomatic and

Pain-Free Elite Swimmers. _Am J Sports Med_ 1997;25(4):454-459.

18. Harrington S, Meisel C, Tate A. A cross-sectional study examining shoulder pain and

disability in Division 1 female swimmers. _J Sports Rehab_ 2014;23:66-75.

19. Torres R, Gomes J. Measurement of glenohumeral internal rotation in asymptommatic

tennis players and swimmers. _Am J Sports Med_ 2009 37(5):1017-1023.

20. Roy J-S, MacDermid J, Boyd K, et al. Rotational strength, range of motion, and

function in people with unaffected shoulders from various stages of life. _Sports Med_

_Arthrosc Rehabil Ther Technol_ 2009;1(4):1-10.

21. Yanai T, Hay J. Shoulder impingement in frony-crawl swimming: II analysis of

stroking technique. _Med Sc Sport Exerc_ 2000;32:30-40.

16

22. Beach M, Whitney S, Dickoff-Hoffman S. Relationship of shoulder flexibility,

strength and endurance to shoulder pain in competitive swimmers. _J Orthop Sports_

_Phys Ther_ 1992;16(6):262-268.

23. Riemann B, Davies G, Ludwig L, et al. Hand-held dynamometer testing of the

internal and external rotator musculature based on selected positions to establish

normative data and unilateral ratios. _J Sh Elbow Surg_ 2010;19(8):1175-1183.

24. Walker H, Gabbe B, Wajswelner H, et al. Shoulder pain in swimmers: a 12-month

prospective cohort study of incidence and risk factors. _Phys Ther Sport_ 2012;13:243

249.

17

**Figure Legends**

**Figure 1:** Experimental setup for the measurement of a) passive internal rotation (IR) range

of motion (ROM), b) passive external rotation (ER) ROM, c) active IR ROM in supine, d)

active ER ROM in supine, e) active IR ROM in prone, f) active ER ROM in prone.

**Figure 2** : The mean (± SD) internal and external shoulder rotation range of motion (ROM)

measured passively and actively in both supine and prone for dominant and non-dominant

shoulders. \[† \] indicates significant differences between dominant and non-dominant, * indicates

significant differences between execution of rotation ROM: passive, active in supine, active

in prone.

**Figure 3** : Scatter plots of shoulder internal rotation (IR) and external rotation (ER) range of

motion (ROM) measured passively and actively in both supine and prone versus humeral

torsion for dominant (D) and non-dominant (ND) shoulders. Pearson’s correlation

coefficients (r) between each of the measures of ROM and humeral torsion and their

significance value are provided. Bold – significant difference (p\<0.05). Black filled circles

are D and white filled circles are ND.

18

19

20

21

**Table 1: Humeral torsion and shoulder rotation range of motion profile of elite**

**swimming cohort**

**Dominant** **Non-dominant**

**Variable** **Male** **Female** **All** **Male** **Female** **All**

Torsion (degrees) 27 ± 11 27 ± 8 27 ± 10 33 ± 10 28 ± 9 31 ± 10

Passive ROM

(degrees)

Active ROM (supine)
(degrees)

Active ROM (prone)
(degrees)

IR 59 ± 14 63 ± 13 61 ± 14 63 ± 12 63 ± 14 63 ± 13

ER 104 ± 12 106 ± 13 105 ± 12 101 ± 13 106 ± 12 103 ± 13

Total 164 ± 19 169 ± 18 166 ± 19 164 ± 17 169 ± 19 166 ± 18

IR 49 ± 13 49 ± 12 49 ± 13 52 ± 11 51 ± 11 51 ± 11

ER 89 ± 15 90 ± 12 90 ± 14 86 ± 12 90 ± 12 87 ± 12

Total 138 ± 13 140 ± 16 139 ± 14 137 ± 15 140 ± 17 139 ± 16

IR 32 ± 17 30 ± 15 31 ± 16 35 ± 15 32 ± 18 34 ± 16

ER 89 ± 15 95 ± 14 92 ± 15 88 ± 13 91 ± 16 89 ± 14

Total 121 ± 15 124 ± 16 122 ± 15 122 ± 13 123 ± 17 122 ± 15

22
